@@ -57,12 +57,7 @@ class Locus(object):
             contig,
             start,
             end,
-            strand,
-            gene_id=None,
-            gene_name=None,
-            transcript_id=None,
-            transcript_name=None,
-            exon_id=None):
+            strand):
         """
         contig : str
             Chromosome or other sequence name in the reference assembly
@@ -76,6 +71,7 @@ class Locus(object):
         strand : str
             Should we read the locus forwards ('+') or backwards ('-')?
         """
+
         self.contig = normalize_chromosome(contig)
         self.strand = normalize_strand(strand)
 
@@ -101,6 +97,17 @@ class Locus(object):
     def __repr__(self):
         return str(self)
 
+    def __len__(self):
+        return self.end - self.start + 1
+
+    def __eq__(self, other):
+        return (
+            self.contig == other.contig and
+            self.start == other.start and
+            self.end == other.end and
+            self.strand == other.strand
+        )
+
     @property
     def length(self):
         return self.end - self.start + 1
@@ -115,7 +122,7 @@ class Locus(object):
         else:
             return self.end - position
 
-    def range_offset(self, start, end):
+    def offset_range(self, start, end):
         """
         Database start/end entries are always ordered such that
         start < end. This makes computing a relative position (e.g. of a stop
